import React, { useEffect, useState } from 'react';
import { ReportingForm } from './reporting/ReportingForm';
import { AlertingForm } from './alerting/AlertingForm';
import { Button, Icon } from '../components';
import { AddItem } from './components/AddItem';
import { StartScreen } from './components/StartScreen';
import { MonitorType } from './components/Sidebar';

type Props = {
  active: string;
  activeCategory: MonitorType | undefined;
  adding: boolean;
  setAdding: (val: boolean) => void;
  setActiveCategory: (val: MonitorType | undefined) => void;
};

export function SettingsPanel(props: Props) {
  const [contacts, setContacts] = useState<string[]>([]);

  const getContacts = (): string[] => ['Jan', 'Piet'];

  useEffect(() => {
    if (!contacts) {
      const userContacts = getContacts();
      setContacts(userContacts);
    }
  }, []);

  return props.activeCategory ? (
    <div className="w-3/4 p-4">
      {props.adding ? (
        <AddItem category={props.activeCategory} />
      ) : (
        props.active &&
        props.activeCategory && (
          <div>
            {props.activeCategory === 'report' ? (
              <ReportingForm activeTemplate={props.active} />
            ) : (
              <AlertingForm activeTemplate={props.active} />
            )}
          </div>
        )
      )}
      <div className="flex justify-end mt-2">
        <Button label="Delete" variantType="secondary" variant="outline" />
        <Button label="Save" variantType="primary" className="ml-2" />
      </div>
    </div>
  ) : (
    <StartScreen setAdding={props.setAdding} setActiveCategory={props.setActiveCategory} />
  );
}
